@@ -1,5 +1,6 @@
 from adamo_calibrator.calibrator.helpers import calc_quadrant, get_adyacent, \
     same_axis, scale_axis
+from adamo_calibrator.calibrator.constants import calc
 from adamo_calibrator.export.xinput import XInput
 from random import randint
 from sys import exit
@@ -24,9 +25,6 @@ class Calibrator:
         self.swapxy = False
         self.inversex = False
         self.inversey = False
-
-        self.new_device = False
-
         if fake:
             self.device = 'fake'
             self.old_prop_value = [0, 1000, 0, 1000]
@@ -37,8 +35,8 @@ class Calibrator:
             self.get_device()
 
     def get_device(self):
-        #This function loads an calibratable device from xinput, if detect more
-        #than one device, this select the first.
+        # This function loads an calibratable device from xinput, if detect
+        # more than one device, this select the first.
         devices = XInput.get_device_with_prop('Evdev Axis Calibration',
                                               False)
         if len(devices) == 0:
@@ -47,11 +45,8 @@ class Calibrator:
         if len(devices) > 1:
             print "More than one devices detected. Using last."
 
-        (device_name, self.device, setted) = devices[-1]
-
-        if device_name == 'eGalax Inc. USB TouchController':
-            self.new_device = True
-
+        # Get device with format (Name, DevID, setted)
+        self.device = devices[-1][1]
         self.get_device_prop_range()
         # This reset calibration to defaults values because recalibration
         # errors
@@ -76,8 +71,8 @@ class Calibrator:
                             int(float(self.old_prop_value[3]))))
 
     def set_screen_prop(self, width, height):
-        #This function set the screen width and height and realize some
-        #calcules respecting of points and the separation between this
+        # This function set the screen width and height and realize some
+        # calcules respecting of points and the separation between this
         self.width = width
         self.height = height
 
@@ -90,8 +85,8 @@ class Calibrator:
                        (block_x * 7, block_y * 7)]
 
     def calc_new_axis(self):
-        #This function calcules a new axis of references, based on clicks and
-        #old axis references witch uses in a transform with new axis
+        # This function calcules a new axis of references, based on clicks and
+        # old axis references witch uses in a transform with new axis
         width = self.width
         height = self.height
 
@@ -132,7 +127,7 @@ class Calibrator:
         self.y_max = scale_axis(y_max, old_ymax, old_ymin, height, 0)
 
     def doubleclick(self, x, y):
-        #This function detects if a doubleclick was made
+        # This function detects if a doubleclick was made
         doubleclick = False
         clicks = self.clicks
         for key in clicks:
@@ -143,7 +138,7 @@ class Calibrator:
         return doubleclick
 
     def misclick(self, x, y):
-        #This function detects if a misclick was made.
+        # This function detects if a misclick was made.
         nclicks = self.nclicks
         threshold = self.threshold_misclick
         misclick = False
@@ -171,48 +166,25 @@ class Calibrator:
         self.nclicks = 0
         self.set_screen_prop(width, height)
 
-    def check_axis_new(self, x, y):
-        #This function checks if a inversion of axis or swapping of axis is
-        #needed.
-        (xp, yp) = self.points_clicked[-1]
-        quadrant_exp = calc_quadrant(self.width, self.height, xp, yp)
-        quadrant = calc_quadrant(self.width, self.height, x, y)
-        if (quadrant_exp in [1, 4] and quadrant in [2, 3]) or \
-                (quadrant_exp in [2, 3] and quadrant in [1, 4]):
-            self.inversex = True
-        if (quadrant_exp in [1, 2] and quadrant in [3, 4]) or \
-                (quadrant_exp in [3, 4] and quadrant in [1, 2]):
-            self.inversey = True
+    def check_axis(self):
+        # This function checks if a inversion of axis or swapping of axis is
+        # needed.
+        # Getting the keys ordered by quadrant.
+        ordered_keys = sorted(self.clicks, key=lambda k: (k[1], k[0]))
 
-    def check_axis(self, x, y):
-        #This function checks if a inversion of axis or swapping of axis is
-        #needed.
-        (xp, yp) = self.points_clicked[-1]
-        quadrant_exp = calc_quadrant(self.width, self.height, xp, yp)
-        quadrant = calc_quadrant(self.width, self.height, x, y)
-        if (quadrant == 1 and quadrant_exp == 2) or \
-                (quadrant == 2 and quadrant_exp == 1) or \
-                (quadrant == 3 and quadrant_exp == 4) or \
-                (quadrant == 4 and quadrant_exp == 3):
-            self.inversex = True
-        elif (quadrant == 1 and quadrant_exp == 3) or \
-                (quadrant == 3 and quadrant_exp == 1) or \
-                (quadrant == 2 and quadrant_exp == 4) or \
-                (quadrant == 4 and quadrant_exp == 2):
-            self.inversey = True
-        elif (quadrant == 1 and quadrant_exp == 4) or \
-                (quadrant == 4 and quadrant_exp == 1) or \
-                (quadrant == 2 and quadrant_exp == 3) or \
-                (quadrant == 3 and quadrant_exp == 2):
-            self.swapxy = True
-        elif (quadrant == quadrant_exp):
-            self.inversex = False
-            self.inversey = False
-            self.swapxy = False
+        # Making the key
+        calc_key = ''
+        for key in ordered_keys:
+            x, y = self.clicks[key]
+            calc_key += '{}'.format(calc_quadrant(self.width, self.height, x,
+                                                  y))
+
+        # Getting the settings.
+        self.inversex, self.inversey, self.swapxy = calc[calc_key]
 
     def add_click(self, click):
-        #This function register a new click made by user and return an error
-        #if it's need
+        # This function register a new click made by user and return an error
+        # if it's need
         (x, y) = click
         error = None
         if self.doubleclick(x, y):
@@ -223,14 +195,10 @@ class Calibrator:
             expected = self.points_clicked[-1]
             self.clicks[expected] = (x, y)
             self.nclicks += 1
-            if self.new_device:
-                self.check_axis_new(x, y)
-            else:
-                self.check_axis(x, y)
         return error
 
     def get_next_point(self):
-        #This function returns the next point if is available
+        # This function returns the next point if is available
         if len(self.points) > 0:
             if len(self.points_clicked) == 0:
                 point = self.points.pop(randint(0, len(self.points) - 1))
@@ -246,9 +214,10 @@ class Calibrator:
         return point
 
     def finish(self):
-        #This function save a new axis reference and inverse the values if
-        #need.
-        xinput = XInput()
+        # This function save a new axis reference and inverse the values if
+        # need.
+        self.check_axis()
+
         inversex = 1 if self.inversex else 0
         inversey = 1 if self.inversey else 0
         x_min = self.x_min
@@ -256,11 +225,7 @@ class Calibrator:
         y_min = self.y_min
         y_max = self.y_max
 
-        # If the difference of the calibration is higher than X axis, the
-        # calibrator must swap axis.
-        if (y_max - y_min) > (x_max - x_min):
-            self.swapxy = True
-
+        xinput = XInput()
         if self.swapxy:
             xinput.set_prop(self.device, '"Evdev Axes Swap"', '1')
             inversex, inversey = inversey, inversex
