@@ -1,15 +1,15 @@
 
 def calc_quadrant(w, h, x, y):
     """ Screen Quadrants
-        +---+---+
-        | 3 | 4 |
-        +---+---+
-        | 2 | 1 |
+        +---+---+       1) x < w/2 && y < h/2
+        | 1 | 2 |       2) x > w/2 && y < h/2
+        +---+---+       3) x < w/2 && y > h/2
+        | 3 | 4 |       4) x > w/2 && y > h/2
         +---+---+
     """
-    if (x - w / 2) > 0 and (y - h / 2) < 0:
+    if (x - w / 2) < 0 and (y - h / 2) < 0:
         quadrant = 1
-    elif (x - w / 2) < 0 and (y - h / 2) < 0:
+    elif (x - w / 2) > 0 and (y - h / 2) < 0:
         quadrant = 2
     elif (x - w / 2) < 0 and (y - h / 2) > 0:
         quadrant = 3
@@ -44,5 +44,8 @@ def scale_axis(cx, to_max, to_min, from_max, from_min):
         x = to_max
     if (x < to_min):
         x = to_min
-
     return x
+
+
+def printable(a, b, c, d):
+    return '{}{}{}{}'.format(a, b, c, d)
