@@ -4,7 +4,7 @@ from zaguan.controller import WebContainerController
 from adamo_calibrator.ui.web.actions import CalibratorControllerActions
 
 from adamo_calibrator.calibrator.calibrator import Calibrator
-from adamo_calibrator.settings import NPOINTS, MOSTRAR_CURSOR
+from adamo_calibrator.settings import NPOINTS, SHOW_CURSOR
 from adamo_calibrator.ui.helpers import load_locales
 #from adamo_calibrator.ui.web.helpers import get_base_data
 
@@ -63,7 +63,7 @@ class CalibratorController(WebContainerController):
 
         self._calc_verification_point(width, height)
 
-        data['mostrar_cursor'] = MOSTRAR_CURSOR
+        data['show_cursor'] = SHOW_CURSOR
         data['timeout'] = self.timeout
         data['fast_start'] = self.fast_start
         data['auto_close'] = self.auto_close
@@ -84,7 +84,12 @@ class CalibratorController(WebContainerController):
         self.state = 'calibrating'
         self.nerror = 0
         self.calibrator.reset()
-        self.send_command('reset')
+
+        width = self.calibrator.width
+        height = self.calibrator.height
+        self._calc_verification_point(width, height)
+        self.send_command('reset', self.verification_point)
+
         next = self.calibrator.get_next_point()
         self.send_command('move_pointer', next)
 
@@ -94,11 +99,9 @@ class CalibratorController(WebContainerController):
         # calibración ya que considera de que la pantalla no está correctamemte
         # calibrada
         recalibrate = False
-        width = self.calibrator.width
-        height = self.calibrator.height
-        misclick_threshold = self.calibrator.threshold_misclick
-        if abs(width / 2 - x) > misclick_threshold or \
-                abs(height / 2 - y) > misclick_threshold:
+        misclick_threshold = 16
+        if abs(self.verification_point[0] - x) > misclick_threshold or \
+                abs(self.verification_point[1] - y) > misclick_threshold:
             recalibrate = True
 
         return recalibrate
@@ -136,8 +139,10 @@ class CalibratorController(WebContainerController):
                 self.send_command('error', error)
         elif state == 'end':
             if self._check_last_click(data):
+                print "Reset", data
                 self.reset()
             else:
+                print "Close"
                 self.quit(data)
 
     def quit(self, data):
